@@ -1,4 +1,4 @@
-# Copyright 2019-2020 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@ from asreview.utils import get_random_state
 
 
 class UndersampleBalance(BaseBalance):
-    """Balancing class that undersamples the data with a given ratio.
+    """Undersampling balance strategy.
 
     This undersamples the data, leaving out excluded papers so that the
     included and excluded papers are in some particular ratio (closer to one).
@@ -34,6 +34,7 @@ class UndersampleBalance(BaseBalance):
     """
 
     name = "undersample"
+    label = "Undersampling"
 
     def __init__(self, ratio=1.0, random_state=None):
         """Initialize the undersampling balance strategy."""
