@@ -1,4 +1,4 @@
-# Copyright 2019 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2020 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@ import logging
 
 import numpy as np
 
+from asreview.compat import convert_id_to_idx
 from asreview.init_sampling import sample_prior_knowledge
 from asreview.review import BaseReview
 
@@ -46,7 +47,7 @@ class ReviewSimulate(BaseReview):
     n_prior_excluded: int
         Sample n prior excluded papers.
     prior_idx: int
-        Prior indices by id.
+        Prior indices by row number.
     n_papers: int
         Number of papers to review during the active learning process,
         excluding the number of initial priors. To review all papers, set
@@ -81,20 +82,14 @@ class ReviewSimulate(BaseReview):
         self.n_prior_included = n_prior_included
         self.n_prior_excluded = n_prior_excluded
 
+        # check for partly labeled data
         labels = as_data.labels
         labeled_idx = np.where((labels == 0) | (labels == 1))[0]
-
         if len(labeled_idx) != len(labels):
-            logging.warning("Simulating partial review, ignoring unlabeled"
-                            f" papers (n={len(labels)-len(labeled_idx)}.")
-            as_data = as_data.slice(labeled_idx)
-            labels = as_data.labels
+            raise ValueError("Expected fully labeled dataset.")
 
         if prior_idx is not None and len(prior_idx) != 0:
-            id_to_index = {as_data.df.index.values[i]: i
-                           for i in range(len(as_data))}
-            start_idx = np.array([id_to_index[idx] for idx in prior_idx],
-                                 dtype=int)
+            start_idx = prior_idx
         else:
             start_idx = as_data.prior_data_idx
             if len(start_idx) == 0 and n_prior_included + n_prior_excluded > 0:
